@@ -16,9 +16,12 @@ namespace Rcpp{
             public:
                 typedef typename Rep_len::Vec Vec ;
                 
-                const_iterator( const Rep_len& data_, R_xlen_t index_ ) :
-                    data(data_.data), n(data_.n), index(index_), src_index(index % n ) {}
+                const_iterator( const Vec& data_, R_xlen_t n_, R_xlen_t index_ ) : 
+                    data(data_), n(n_), index(index_), src_index(index % n ){}
                 
+                const_iterator( const Rep_len& data_, R_xlen_t index_ ) :
+                    const_iterator( data_.data, data_.n, index_ ){}
+                    
                 inline const_iterator& operator++(){ 
                     index++;
                     src_index++ ; if( src_index == n ) src_index = 0 ;
@@ -41,6 +44,10 @@ namespace Rcpp{
                 inline bool operator==( const const_iterator& other ){ return index == other.index; }
                 inline bool operator!=( const const_iterator& other ){ return index != other.index; }
                 
+                inline const_iterator operator+( R_xlen_t n_ ) const {
+                    return const_iterator( data, n, index + n_) ;
+                }
+                
             private:
                 const Vec& data ;
                 R_xlen_t n, index, src_index;
@@ -57,7 +64,12 @@ namespace Rcpp{
             inline R_xlen_t size() const { return len ; }
         
             template <typename Target>
-            inline void apply(Target& target) const {
+            inline void apply( Target& target ) const {
+                apply_serial(target) ;    
+            }
+        
+            template <typename Target>
+            inline void apply_serial(Target& target) const {
                 if (n >= len) {
                     std::copy_n(data.begin(), len, target.begin() );
                     return;
@@ -78,8 +90,8 @@ namespace Rcpp{
             }
             
             template <typename Target>
-            inline void apply_parallel( Target& target, int nthreads ) const {
-                apply(target) ;    
+            inline void apply_parallel( Target& target ) const {
+                apply_serial(target) ;    
             }
         
             inline const_iterator begin() const { return const_iterator( *this, 0 ) ; }
