@@ -4,12 +4,12 @@
 namespace Rcpp{
 
     template <int RTYPE, typename Mat>
-    class MatrixColumn : public SugarVectorExpression<RTYPE,true,MatrixColumn<RTYPE,Mat>> {
+    class MatrixColumn : public SugarVectorExpression< typename traits::storage_type<RTYPE>::type, MatrixColumn<RTYPE,Mat> > {
     public:
+        typedef typename traits::storage_type<RTYPE>::type value_type ;
         typedef typename Mat::iterator iterator;
-        typedef typename Mat::Proxy Proxy ;
         typedef typename Mat::const_iterator const_iterator;
-        typedef typename Mat::const_Proxy const_Proxy;
+        typedef typename Mat::Proxy Proxy ;
         
         MatrixColumn( Mat& mat_, int i) : mat(mat_), index(i), n(mat.nrow()){}
         
@@ -20,23 +20,17 @@ namespace Rcpp{
             return *this ;    
         }
         
-        template <bool NA, typename Vec>
-        MatrixColumn& operator=( const SugarVectorExpression<RTYPE,NA,Vec>& expr ){
-            if( expr.size() != size() ) throw incompatible_dimensions() ;
+        template <typename eT, typename Expr>
+        MatrixColumn& operator=( const SugarVectorExpression<eT, Expr>& expr ){
+            if( expr.size() != size() ) 
+                stop("incompatible number of elements, expecting '%d', got '%d'", size(), expr.size() );
             expr.apply(*this) ;
             return *this;
         }
-        
-        template < template <class> class StoragePolicy >
-        MatrixColumn& operator=( const Vector<RTYPE,StoragePolicy>& vec ){
-            if( vec.size() != size() ) throw incompatible_dimensions() ;
-            std::copy( vec.begin(), vec.end(), begin() );
-            return *this;
-        }
-        
+         
         inline int size() const { return n ;}
         inline Proxy operator[]( int i){ return mat[ index*n + i] ; }
-        inline const_Proxy operator[]( int i) const { return mat[ index*n + i] ; }
+        inline const Proxy operator[]( int i) const { return mat[ index*n + i] ; }
         
         inline iterator begin() { return mat.begin() + index * n ; }
         inline iterator end(){ return mat.begin() + (index+1)* n ; }
